! app.css
<< https://cdn.datatables.net/2.3.7/css/dataTables.dataTables.min.css

! app.js
<< https://code.jquery.com/jquery-3.7.1.min.js
<< https://cdn.datatables.net/2.3.7/js/dataTables.min.js
< js/DatatableGroup.js
